@@ -6,6 +6,9 @@ python src/compile
 cp tunapie /usr/local/bin
 rm -rf /usr/local/share/tunapie
 mkdir /usr/local/share/tunapie
-cp src/*.py src/*.pyc src/*.jpg /usr/local/share/tunapie
+cp src/*.py src/*.pyc src/*.png /usr/local/share/tunapie
+mkdir -p /usr/local/share/pixmaps
+cp src/tplogo.xpm /usr/local/share/pixmaps/
+mkdir -p /usr/local/man/man1
 cp tunapie.1 /usr/local/man/man1
 cp tunapie.desktop /usr/local/share/applications
