@@ -172,7 +172,8 @@ class RecordStream(wx.Dialog):
 
     def __init__(self, parent):
         self._init_ctrls(parent)
-        timenow=time.localtime(time.time())
+        self.shoutice = parent.shoutice 
+	timenow=time.localtime(time.time())
         #date,time=str(mx.DateTime.now()).split()
         self.year,self.month,self.day=str(timenow[0]),str(timenow[1]),str(timenow[2])
         self.hours,self.minutes=str(timenow[3]),str(timenow[4])
@@ -218,16 +219,19 @@ class RecordStream(wx.Dialog):
         ripper=self.recordoptions[1]
         pls=self.recordoptions[2]
         rdir=self.recordoptions[3]
-        playlist=urllib.urlopen(pls)
-        tempfile=playlist.read()
-        url=tempfile[tempfile.find('//')+2:tempfile.find('\n',50)]
+        if self.shoutice == 1:
+            playlist=urllib.urlopen(pls)
+            tempfile=playlist.read()
+            url=tempfile[tempfile.find('//')+2:tempfile.find('\n',50)]
+        else:
+            url=pls[pls.find('//')+2:]
         r=ripper.split(' ')
         if (self.nowradio.GetValue()==True):
             args=' -e \"'+r[0]
         else:
             args=r[0]
         args+=' http://'+url
-        i=0
+	i=0
         directoryset=0
         for argument in r:
             i+=1
@@ -241,7 +245,6 @@ class RecordStream(wx.Dialog):
         if (self.nowradio.GetValue()==True):
             args+='\"'
             tuner.recordselection(self.recordoptions[0], args)
-            print self.recordoptions[0], args
             self.Close()
             return
         args +=' -l '+str((self.stophours.GetValue()*3600)+(self.stopmins.GetValue()*60))     
