@@ -1,5 +1,5 @@
 #Boa:App:BoaApp
-#TunaPie (c)2005-2006 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -18,23 +18,26 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 0.0.7 17/10/06
+#Version 2.1 04/09/07
 
 import wxversion
-wxversion.select("2.6")
+wxversion.ensureMinimal("2.6")
 import wx
-
-import TunerFrame1
+import tunapie2_main
 import os
 import sys
 
-modules ={u'TunerFrame1': [1, 'Main frame of Application', u'TunerFrame1.py']}
+modules ={u'tunapie2_main': [1, 'Main frame of Application', u'tunapie2_main.py']}
 
 class BoaApp(wx.App):
     def OnInit(self):
+        path=sys.argv[0][:sys.argv[0].find('Tunapie.py')]
+        try: os.chdir(path)
+        except OSError: pass
         wx.InitAllImageHandlers()
-        frame = TunerFrame1.create(None)
-        frame.Show()
+        self.main = tunapie2_main.create(None)
+        self.main.Show()
+        self.SetTopWindow(self.main)
         return True
 
 def main():
