@@ -1,5 +1,5 @@
 #Boa:Dialog:StreamInfo
-#TunaPie (c)2005-2006 James Stone. Released under the GNU GPL.
+#TunaPie (c)2005-2008 James Stone. Released under the GNU GPL.
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -18,18 +18,19 @@
 #Written using Boa-Constructor.
 #http://boa-constructor.sourceforge.net/
 #
-#Version 0.0.3 26/09/06
+#Version 0.1.2 02/05/07
 
 
 import wx
 import wx.lib.stattext
+import tuner
 
 def create(parent):
     return StreamInfo(parent)
 
-[wxID_STREAMINFO, wxID_STREAMINFOINFOBOX, wxID_STREAMINFOOKBUTTON, 
- wxID_STREAMINFOURLLABEL, 
-] = [wx.NewId() for _init_ctrls in range(4)]
+[wxID_STREAMINFO, wxID_STREAMINFOINFOBOX, wxID_STREAMINFOINFOBUTTON, 
+ wxID_STREAMINFOOKBUTTON, wxID_STREAMINFOURLLABEL, 
+] = [wx.NewId() for _init_ctrls in range(5)]
 
 class StreamInfo(wx.Dialog):
     def _init_ctrls(self, prnt):
@@ -43,13 +44,13 @@ class StreamInfo(wx.Dialog):
 
         self.urllabel = wx.lib.stattext.GenStaticText(ID=wxID_STREAMINFOURLLABEL,
               label=u'Info:', name=u'urllabel', parent=self, pos=wx.Point(16,
-              16), size=wx.Size(21, 15), style=0)
+              16), size=wx.Size(21, 17), style=0)
         self.urllabel.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
               u'Helvetica'))
         self.urllabel.SetThemeEnabled(True)
 
         self.okbutton = wx.Button(id=wxID_STREAMINFOOKBUTTON, label=u'OK',
-              name=u'okbutton', parent=self, pos=wx.Point(184, 216),
+              name=u'okbutton', parent=self, pos=wx.Point(280, 216),
               size=wx.Size(85, 30), style=0)
         self.okbutton.SetFont(wx.Font(8, wx.SWISS, wx.NORMAL, wx.NORMAL, False,
               u'Helvetica'))
@@ -62,6 +63,13 @@ class StreamInfo(wx.Dialog):
               size=wx.Size(352, 184), style=0)
         self.infobox.SetThemeEnabled(True)
 
+        self.infobutton = wx.Button(id=wxID_STREAMINFOINFOBUTTON, label=u'Info',
+              name=u'infobutton', parent=self, pos=wx.Point(100, 216),
+              size=wx.Size(85, 30), style=0)
+        self.infobutton.Show(True)
+        self.infobutton.Bind(wx.EVT_BUTTON, self.OnInfobuttonButton,
+              id=wxID_STREAMINFOINFOBUTTON)
+
     def __init__(self, parent):
         self._init_ctrls(parent)
 
@@ -75,11 +83,28 @@ class StreamInfo(wx.Dialog):
     def OnOkbuttonButton(self, event):
         self.Close()
         
-    def FillInfo (self, info):
-        x=0
+    def FillInfo (self, info, browser=""):
+        okurl=0
+        self.browser=browser
         for item in info:
             itemstrip=item.rstrip('\n')
             self.infobox.Append(itemstrip)
-    
-    
-            
+            print(itemstrip)
+            if itemstrip.find("File")==0:
+                if not(okurl):
+                    url=itemstrip[itemstrip.find("=")+1:]
+                    beginurl=url.find("//")+3
+                    endurl=url[beginurl:].find("/")
+                    if endurl==-1:
+                        okurl=1
+                        self.url=url
+                    else:
+                        self.url=url[:beginurl+endurl]
+
+    def infobuttonhide(self):
+        self.infobutton.Hide()
+
+    def OnInfobuttonButton(self, event):
+        try: tuner.showpage(self.browser,self.url)
+        except AttributeError: 
+            pass
