@@ -412,7 +412,7 @@ class TunapieFrame(wx.Frame):
             0,1,2,3,4,5
         self.adult=tuner.adultset()
         self.rdir=self.home+'/.tunapie/streamripper'
-        self.shoutice=1 #0 is icecast server 1 is shoutcast
+        self.shoutice=0 #0 is icecast server 1 is shoutcast
         self.maxd=100
         self.newsize=8
         self.setgenreboxradio()
@@ -455,6 +455,10 @@ class TunapieFrame(wx.Frame):
                 self.videoplayer='mplayer'
             elif commands.getoutput("which xine").find("xine")>-1:
                 self.videoplayer='xine'
+            elif commands.getoutput("totem").find("totem")>-1:
+                self.mediaplayer='totem'
+            elif commands.getoutput("amarok").find("amarok")>-1:
+                self.mediaplayer='amarok' 
             else:
                 print("No videoplayer found\n")
                 missing_players.append("No videoplayer found.")
@@ -1005,6 +1009,7 @@ class TunapieFrame(wx.Frame):
                         self.updatemain()
                         self.MainListCtrl.Select(0)
                         self.MainListCtrl.SetFocus()
+                        print 'Done.'
                         return
 
     def OnMainListCtrlListColClick(self, event):
